# `ddtrace`

[![CircleCI](https://circleci.com/gh/DataDog/dd-trace-py/tree/main.svg?style=svg)](https://circleci.com/gh/DataDog/dd-trace-py/tree/main)
[![PypiVersions](https://img.shields.io/pypi/v/ddtrace.svg)](https://pypi.org/project/ddtrace/)
[![Pyversions](https://img.shields.io/pypi/pyversions/ddtrace.svg?style=flat)](https://pypi.org/project/ddtrace/)

<img align="right" src="https://user-images.githubusercontent.com/6321485/167082083-53f6e48f-1843-4708-9b98-587c94f7ddb3.png" alt="bits python" width="200px"/>

This library powers [Distributed Tracing](https://docs.datadoghq.com/tracing/),
 [Continuous Profiling](https://docs.datadoghq.com/tracing/profiler/),
 [Error Tracking](https://docs.datadoghq.com/tracing/error_tracking/),
 [Test Optimization](https://docs.datadoghq.com/tests/),
 [Deployment Tracking](https://docs.datadoghq.com/tracing/deployment_tracking/),
 [Code Hotspots](https://docs.datadoghq.com/tracing/profiler/connect_traces_and_profiles/),
 [Dynamic Instrumentation](https://docs.datadoghq.com/dynamic_instrumentation/),
 and more.

To get started with tracing, check out the [product documentation][setup docs] or the [glossary][visualization docs].

For advanced usage and configuration information, check out the [library documentation][api docs].

To get started as a contributor, see [the contributing docs](https://ddtrace.readthedocs.io/en/stable/contributing.html) first.

For information about the bug/security fix and maintenance policy, see the [versioning docs][versioning docs].

[setup docs]: https://docs.datadoghq.com/tracing/setup/python/
[api docs]: https://ddtrace.readthedocs.io/
[visualization docs]: https://docs.datadoghq.com/tracing/visualization/
[versioning docs]: https://github.com/DataDog/dd-trace-py/blob/main/docs/versioning.rst#release-support
